-- widget title=Assessment overview, row=15, col=0, size_x=8, size_y=4

## Storage Summary
-  External Locations

-  Mount Points

[documentation](https://github.com/databrickslabs/ucx/blob/main/docs/assessment.md)
